<?php
/**
* Community Builder (TM)
* @version $Id: $
* @package CommunityBuilder
* @copyright (C) 2004-2015 www.joomlapolis.com / Lightning MultiCom SA - and its licensors, all rights reserved
* @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU/GPL version 2
* 
* 2019-09-21 
* Modified for the jDownloads 3.9 series by Arno Betz and ColinM - www.jdownloads.com
*/

use CBLib\Database\Table\Table;
use CBLib\Language\CBTxt;
use CB\Database\Table\PluginTable;
use CB\Database\Table\TabTable;
use CB\Database\Table\UserTable;
use Joomla\CMS\Router\Route;

if ( ! ( defined( '_VALID_CB' ) || defined( '_JEXEC' ) || defined( '_VALID_MOS' ) ) ) { die( 'Direct Access to this location is not allowed.' ); }

/**
 * Class HTML_cbjdownloadsTab
 * Template for CB jDownloads
 */
class HTML_cbjdownloadsTab
{
	/**
	 * Renders the Downloads tab
	 *
	 * @param  Table[]      $rows       Download to render
	 * @param  cbPageNav    $pageNav    Pagination
	 * @param  boolean      $searching  Currently searching
	 * @param  string[]     $input      HTML of input elements
	 * @param  UserTable    $viewer     Viewing user
	 * @param  UserTable    $user       Viewed user
	 * @param  stdClass     $model      The model reference
	 * @param  TabTable     $tab        Current Tab
	 * @param  PluginTable  $plugin     Current Plugin
	 * @return string                   HTML
	 */
	static public function showJdownloadsTab( $rows, $pageNav, $searching, $input, $viewer, $user, /** @noinspection PhpUnusedParameterInspection */ $model, $tab, /** @noinspection PhpUnusedParameterInspection */ $plugin )
	{
		global $_CB_framework;

		$tabPaging				=	$tab->params->get( 'tab_paging', 1 );
		$canSearch				=	( $tab->params->get( 'tab_search', 1 ) && ( $searching || $pageNav->total ) );

		$return					=	'<div class="downloadsTab">'
								.		'<form action="' . $_CB_framework->userProfileUrl( $user->id, true, $tab->tabid ) . '" method="post" name="downloadForm" id="downloadForm" class="downloadForm">';

		if ( $canSearch ) {
			$return				.=			'<div class="downloadsHeader row" style="margin-bottom: 10px;">'
								.				'<div class="col-sm-offset-8 col-sm-4 text-right">'
								.					'<div class="input-group">'
								.						'<span class="input-group-addon"><span class="fa fa-search"></span></span>'
								.						$input['search']
								.					'</div>'
								.				'</div>'
								.			'</div>';
		}

		$return					.=			'<table class="downloadsContainer table table-hover table-responsive">'
								.				'<thead>'
								.					'<tr>'
								.						'<th style="width: 50%;" class="text-left">' . CBTxt::T( 'CBJDOWNLOADS_DOWNLOADS' ) . '</th>'
								.						'<th style="width: 30%;" class="text-left hidden-xs">' . CBTxt::T( 'CBJDOWNLOADS_CATEGORY' ) . '</th>'
								.						'<th style="width: 22%;" class="text-right hidden-xs">' . CBTxt::T( 'CBJDOWNLOADS_CREATED' ) . '</th>'
								.					'</tr>'
								.				'</thead>'
								.				'<tbody>';

		if ( $rows ) foreach ( $rows as $row ) {
			
            if ($row->category == 1){
                $row->category_title = '';
            
                $return				.=					'<tr>'
								    .						'<td style="width: 50%;" class="text-left"><a href="' . cbjdownloadsModel::getUrl( $row, true, 'download' ) . '">' . $row->get( 'title' ) . '</a></td>'
								    .						'<td style="width: 30%;" class="text-left hidden-xs">' . CBTxt::T( 'CBJDOWNLOADS_NONE' ) . '</td>'
								    .						'<td style="width: 20%;" class="text-right hidden-xs">' . cbFormatDate( $row->get( 'created' ), true, false ) . '</td>'
								    .					'</tr>';
            } else {
                $return             .=                    '<tr>'
                                    .                        '<td style="width: 50%;" class="text-left"><a href="' . cbjdownloadsModel::getUrl( $row, true, 'download' ) . '">' . $row->get( 'title' ) . '</a></td>'
                                    .                        '<td style="width: 30%;" class="text-left hidden-xs">' . ( $row->get( 'category' ) ? '<a href="' . cbjdownloadsModel::getUrl( $row, true, 'category' ) . '">' . $row->get( 'category_title' ) . '</a>' : CBTxt::T( 'CBJDOWNLOADS_NONE' ) ) . '</td>'
                                    .                        '<td style="width: 20%;" class="text-right hidden-xs">' . cbFormatDate( $row->get( 'created' ), true, false ) . '</td>'
                                    .                    '</tr>';
            }
		} else {
			$return				.=					'<tr>'
								.						'<td colspan="3" class="text-left">';

			if ( $searching ) {
				$return			.=							CBTxt::T( 'CBJDOWNLOADS_NOT_FOUND' );
			} else {
				if ( $viewer->id == $user->id ) {
					$return		.=							CBTxt::T( 'CBJDOWNLOADS_YOU_HAVE_NO_DOWNLOADS' );
				} else {
					$return		.=							CBTxt::T( 'CBJDOWNLOADS_THIS_USER_HAVE_NO_DOWNLOADS' );
				}
			}

			$return				.=						'</td>'
								.					'</tr>';
		}

		$return					.=				'</tbody>';

		if ( $tabPaging && ( $pageNav->total > $pageNav->limit ) ) {
			$return				.=				'<tfoot>'
								.					'<tr>'
								.						'<td colspan="3" class="text-center">'
								.							$pageNav->getListLinks()
								.						'</td>'
								.					'</tr>'
								.				'</tfoot>';
		}

		$return					.=			'</table>'
								.			$pageNav->getLimitBox( false )
								.		'</form>'
								.	'</div>';

		return $return;
	}
}
